Name:		quassel
Version:	0.12.5
Release:	%mkrel 1
Summary:	A modern cross-platform distributed (monolithic) IRC client
Group:		Networking/IRC
License:	GPLv3
URL:		http://quassel-irc.org/
Source0:	http://quassel-irc.org/pub/quassel-%{version}.tar.bz2
Source1:	networks.ini
# Systemd service file and configuration script
Source2:	quasselcore.service
Source3:	quassel.conf

BuildRequires:	pkgconfig(Qt5Core)
BuildRequires:	pkgconfig(Qt5DBus)
BuildRequires:	pkgconfig(Qt5Script)
BuildRequires:	pkgconfig(Qt5Sql)
BuildRequires:	pkgconfig(Qt5Help)
BuildRequires:	pkgconfig(Qt5WebEngine)

BuildRequires:	kf5-macros
BuildRequires:	cmake(KF5ConfigWidgets)
BuildRequires:	cmake(KF5CoreAddons)
BuildRequires:	cmake(KF5Notifications)
BuildRequires:	cmake(KF5NotifyConfig)
BuildRequires:	cmake(KF5TextWidgets)
BuildRequires:	cmake(KF5WidgetsAddons)
BuildRequires:	cmake(KF5XmlGui)

BuildRequires:	pkgconfig(qca2-qt5)
BuildRequires:	pkgconfig(phonon4qt5)
BuildRequires:	pkgconfig(dbusmenu-qt5)
BuildRequires:	git
BuildRequires:	systemd

Requires:	quassel-common = %{version}
Provides:	plasma5-irc-client

%description
Quassel IRC is a modern, cross-platform, distributed IRC client,
meaning that one (or multiple) client(s) can attach to and detach
from a central core -- much like the popular combination of screen
and a text-based IRC client such as WeeChat, but graphical. In
addition to this uniqe feature, we aim to bring a pleasurable,
comfortable chatting experience to all major platforms (including
Linux®, Windows®, and MacOS X® as well as Qtopia-based cell phones
and PDAs), making communication with your peers not only convenient,
but also ubiquitous available.

%files
%{_kf5_bindir}/%{name}
%{_kf5_applicationsdir}/%{name}.desktop

#-----------------------------------------------------------------------

%package	common
Group:		Networking/IRC
Summary:	A modern cross-platform distributed IRC client - Common files
BuildArch:	noarch
Requires:	qt5-database-plugin-sqlite
Requires:	qca-qt5
Recommends:	inxi-quassel

%description	common
A modern, cross-platform, distributed IRC client.
- This is client only, depends on a core server.

%files common
%doc AUTHORS ChangeLog README.md
%{_kf5_iconsdir}/hicolor/*/*/*
%{_kf5_datadir}/pixmaps/%{name}.png
%{_kf5_datadir}/%{name}/
%{_kf5_knotificationsdir}/%{name}.notifyrc

#-----------------------------------------------------------------------

%package	client
Group:		Networking/IRC
Summary:	A modern cross-platform distributed IRC client - Client only
Requires:	%{name}-common = %{version}

%description	client
A modern cross-platform distributed IRC client - Client only.

%files client
%{_kf5_bindir}/quasselclient
%{_kf5_applicationsdir}/quasselclient.desktop

#-----------------------------------------------------------------------

%package	core
Group:		Networking/IRC
Summary:	A modern cross-platform distributed IRC client - Core server
Requires:	%{name}-common = %{version}

# Required for the quassel user
Requires(pre):		shadow-utils
Requires(post):		rpm-helper >= %{rpmhelper_required_version}
Requires(preun):	rpm-helper >= %{rpmhelper_required_version}
Requires(postun):	rpm-helper >= %{rpmhelper_required_version}

%description	core
A modern, cross-platform, distributed IRC client - This is quassel.
core server for clients.

%files core
%{_kf5_bindir}/quasselcore
%config(noreplace) %{_sysconfdir}/%{name}.conf
%dir %attr(-,quassel,quassel) %{_var}/lib/%{name}
%{_unitdir}/quasselcore.service

#-----------------------------------------------------------------------

%prep
%setup -q

%build
%cmake_kf5 \
    -DWANT_MONO=ON \
    -DWITH_KDE=ON \
    -DEMBED_DATA=OFF \
    -DUSE_QT5=ON \
    -DHAVE_SSL=ON
%make_build

%install
%make_install -C build

# Our own defined networks
rm -f %{buildroot}%{_kf5_datadir}/%{name}/networks.ini
install -m 644 %{SOURCE1} %{buildroot}%{_kf5_datadir}/%{name}/

# Note that quassel tend to not update their version very often, so we are better
# off changing their inxi file version with a symbolic link to our real inxi version
# for that we have an inxi-quassel package
rm -f %{buildroot}%{_kf5_datadir}/%{name}/scripts/inxi

# Install systemd service file
mkdir -p %{buildroot}%{_unitdir}
install -m 0644 %{SOURCE2} %{buildroot}%{_unitdir}/

# Install quassel.conf for systemd file
mkdir -p %{buildroot}%{_sysconfdir}
install -m 0644 %{SOURCE3} %{buildroot}%{_sysconfdir}/

# Home directory for quassel user
install -d -m 0750 %{buildroot}%{_var}/lib/%{name}

%pre core
%_pre_useradd %{name} /dev/null /bin/false

%post core
%_post_service quasselcore

%preun core
%_preun_service quasselcore

%postun core
%_postun_userdel %{name}


%changelog
* Fri Apr 27 2018 daviddavid <daviddavid> 0.12.5-1.mga6
  (not released yet)
+ Revision: 1222939
- new version: 0.12.5, fixes security issues (mga#22957)

* Sat Feb 25 2017 daviddavid <daviddavid> 0.12.4-4.mga6
+ Revision: 1087829
- add a systemd service file to the core subpackage

* Thu Aug 11 2016 daviddavid <daviddavid> 0.12.4-3.mga6
+ Revision: 1045532
- remove old inxi script file and recommend inxi-quassel package instead
  * Note that quassel tend to not update their version very often, so we are better
  * off changing their inxi file version with a symbolic link to our real inxi
  * version, for that we have an inxi-quassel package

* Mon Aug 08 2016 daviddavid <daviddavid> 0.12.4-2.mga6
+ Revision: 1044998
- enable SSL support with -DHAVE_SSL=ON
- enable Qt5WebKit and Qt5WebKitWidgets support
- quassel-common requires qca-qt5
- fix location for our own defined networks
- switch KF5 BRs to cmake(KF5xxx)

* Mon Apr 25 2016 daviddavid <daviddavid> 0.12.4-1.mga6
+ Revision: 1006058
- new version: 0.12.4

* Thu Feb 18 2016 daviddavid <daviddavid> 0.12.3-1.mga6
+ Revision: 965938
- new version: 0.12.3
- use more KF5 macros
- remove merged upstream patches

* Thu Feb 18 2016 daviddavid <daviddavid> 0.12.2-3.mga6
+ Revision: 965828
- fix dependency on qt5-database-plugin-sqlite (fixes mga#17791)

* Sun Dec 13 2015 luigiwalser <luigiwalser> 0.12.2-2.mga6
+ Revision: 909791
- add upstream patch to fix DoS in op command

* Fri Aug 14 2015 neoclust <neoclust> 0.12.2-1.mga6
+ Revision: 864667
- New version 0.12.2

* Mon Apr 27 2015 luigiwalser <luigiwalser> 0.10.1-5.mga5
+ Revision: 820782
- add upstream patch to fix CVE-2015-3427

* Wed Apr 08 2015 luigiwalser <luigiwalser> 0.10.1-4.mga5
+ Revision: 819917
- rediff patch from opensuse to fix CVE-2015-2778 and CVE-2015-2779

* Mon Oct 27 2014 luigiwalser <luigiwalser> 0.10.1-3.mga5
+ Revision: 793807
- add upstream patch to fix CVE-2014-8483

* Wed Oct 15 2014 umeabot <umeabot> 0.10.1-2.mga5
+ Revision: 739593
- Second Mageia 5 Mass Rebuild

* Thu Oct 09 2014 luigiwalser <luigiwalser> 0.10.1-1.mga5
+ Revision: 737663
- 0.10.1

* Tue Sep 16 2014 umeabot <umeabot> 0.10.0-2.mga5
+ Revision: 688577
- Mageia 5 Mass Rebuild

* Sun Mar 30 2014 luigiwalser <luigiwalser> 0.10.0-1.mga5
+ Revision: 609903
- 0.10.0

* Thu Nov 28 2013 luigiwalser <luigiwalser> 0.9.2-1.mga4
+ Revision: 553798
- 0.9.2

* Mon Oct 21 2013 umeabot <umeabot> 0.9.1-2.mga4
+ Revision: 541103
- Mageia 4 Mass Rebuild

* Fri Oct 11 2013 luigiwalser <luigiwalser> 0.9.1-1.mga4
+ Revision: 495123
- 0.9.1 (fixes CVE-2013-4422)

* Sun Jun 02 2013 luigiwalser <luigiwalser> 0.9.0-1.mga4
+ Revision: 434860
- 0.9.0

* Sun Jan 13 2013 umeabot <umeabot> 0.8.0-2.mga3
+ Revision: 380105
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Mon Jun 11 2012 luigiwalser <luigiwalser> 0.8.0-1.mga3
+ Revision: 259609
- 0.8.0
- spec cosmetics (from mdv)

* Wed Apr 25 2012 mikala <mikala> 0.7.4-1.mga2
+ Revision: 233248
- Update tarball to 0.7.4

* Wed Sep 14 2011 mikala <mikala> 0.7.3-1.mga2
+ Revision: 143119
- Update tarball to 0.7.3 ( also fix CVE-2011-3354)
 - make common package noarch
 - client really need to requires common
 - remove %%defattr()
 - remove %%clean section
- Use Suggests for quassel-common for quassel-client
- Remove the requires on quassel-common for quassel-client.

* Mon May 02 2011 ahmad <ahmad> 0.7.2-1.mga1
+ Revision: 94189
- Update to 0.7.2

* Tue Mar 15 2011 mikala <mikala> 0.7.1-3.mga1
+ Revision: 71544
- Enable ssl by default on freenode (& add a non ssl server just in case)

* Thu Jan 20 2011 ahmad <ahmad> 0.7.1-2.mga1
+ Revision: 26613
- adapt networks.ini to Mageia
- imported package quassel


* Sun Oct 03 2010 Ahmad Samir <ahmadsamir@mandriva.org> 0.7.1-1mdv2011.0
+ Revision: 582638
- update to 0.7.1

* Sat Sep 18 2010 Ahmad Samir <ahmadsamir@mandriva.org> 0.7.0-1mdv2011.0
+ Revision: 579438
- update to 0.7.0

* Tue Aug 17 2010 Ahmad Samir <ahmadsamir@mandriva.org> 0.7-0.beta1.1mdv2011.0
+ Revision: 571089
- update to 0.7-beta1
- bump qt4-linguist BR to 4.6.0, quassel client now depends on qt4 >= 4.6.0

* Wed Apr 21 2010 Funda Wang <fwang@mandriva.org> 0.6.1-1mdv2010.1
+ Revision: 537634
- new version 0.6.1

* Thu Mar 04 2010 Ahmad Samir <ahmadsamir@mandriva.org> 0.6-0.rc1.1mdv2010.1
+ Revision: 514054
- new upstream release 0.6 rc1

* Tue Mar 02 2010 Ahmad Samir <ahmadsamir@mandriva.org> 0.6-0.beta1.1mdv2010.1
+ Revision: 513672
- really update
- update to 0.6beta1
- fix file list

* Sun Jan 31 2010 Funda Wang <fwang@mandriva.org> 0.5.2-1mdv2010.1
+ Revision: 498812
- New version 0.5.2

* Sun Nov 22 2009 Ahmad Samir <ahmadsamir@mandriva.org> 0.5.1-1mdv2010.1
+ Revision: 468659
- Clean spec file
- Update to new version 0.5.1

* Fri Oct 16 2009 Ahmad Samir <ahmadsamir@mandriva.org> 0.5.0-1mdv2010.0
+ Revision: 457899
- 0.5.0 final

* Tue Sep 29 2009 Nicolas Lécureuil <nlecureuil@mandriva.com> 0.5-0.rc1.3mdv2010.0
+ Revision: 451048
- Remove old source
  Use #mandriva channel as default

* Tue Sep 29 2009 Helio Chissini de Castro <helio@mandriva.com> 0.5-0.rc1.2mdv2010.0
+ Revision: 451001
- Provides kde4-irc-client

* Mon Sep 07 2009 Nicolas Lécureuil <nlecureuil@mandriva.com> 0.5-0.rc1.1mdv2010.0
+ Revision: 432855
- fix version
- Update to 0.5.0Rc1

* Wed Aug 26 2009 Frederik Himpe <fhimpe@mandriva.org> 0.4.3-1mdv2010.0
+ Revision: 421587
- update to new version 0.4.3

* Sun May 31 2009 Nicolas Lécureuil <nlecureuil@mandriva.com> 0.4.2-2mdv2010.0
+ Revision: 381738
- Rebuild against new kde4

* Thu May 28 2009 Nicolas Lécureuil <nlecureuil@mandriva.com> 0.4.2-1mdv2010.0
+ Revision: 380634
- Update to 0.4.2

* Sun May 24 2009 Nicolas Lécureuil <nlecureuil@mandriva.com> 0.4.1-3mdv2010.0
+ Revision: 379176
- Use #mandriva-cooker for cooker

* Sun May 24 2009 Funda Wang <fwang@mandriva.org> 0.4.1-2mdv2010.0
+ Revision: 379162
- fix default channel (bug#51158)

* Tue Apr 14 2009 Helio Chissini de Castro <helio@mandriva.com> 0.4.1-1mdv2009.1
+ Revision: 367244
- Update for upstream bugfix release

* Fri Feb 20 2009 Helio Chissini de Castro <helio@mandriva.com> 0.4.0-1mdv2009.1
+ Revision: 343319
- New upstream version

* Thu Feb 12 2009 Helio Chissini de Castro <helio@mandriva.com> 0.3.1.20090212-1mdv2009.1
+ Revision: 339758
- Update with daily git

* Fri Jan 30 2009 Funda Wang <fwang@mandriva.org> 0.3.1.20090128-5mdv2009.1
+ Revision: 335540
- rebuild

* Thu Jan 29 2009 Helio Chissini de Castro <helio@mandriva.com> 0.3.1.20090128-4mdv2009.1
+ Revision: 335290
- Add our default channels
- Separate common components
- Separate monolithic and client/core packages, to avoid confuse users in which one should use
- Added missing requires for sqlite qt4 plugin

* Wed Jan 28 2009 Helio Chissini de Castro <helio@mandriva.com> 0.3.1.20090128-2mdv2009.1
+ Revision: 334926
- Updating with current quassel git HEAD. Quassel is now the official candidate for kde4 / qt client.

* Sun Jan 18 2009 Nicolas Lécureuil <nlecureuil@mandriva.com> 0.3.1-2mdv2009.1
+ Revision: 331053
- Fix string format error

* Fri Jan 09 2009 Buchan Milne <bgmilne@mandriva.org> 0.3.1-1mdv2009.1
+ Revision: 327394
- New version 0.3.1

* Tue Sep 30 2008 Buchan Milne <bgmilne@mandriva.org> 0.3.0.1-1mdv2009.0
+ Revision: 290173
- import quassel


